package com.hw.mes.service;

import java.util.List;
import com.hw.mes.domain.MesBasePalletInfo;
import com.hw.mes.domain.vo.MesPalletInfoBindVo;
import org.springframework.transaction.annotation.Transactional;

/**
 * 托盘信息Service接口
 *
 * @author Yinq
 * @date 2024-01-26
 */
public interface IMesBasePalletInfoService
{
    /**
     * 查询托盘信息
     *
     * @param palletInfoId 托盘信息主键
     * @return 托盘信息
     */
    public MesBasePalletInfo selectMesBasePalletInfoByPalletInfoId(Long palletInfoId);

    /**
     * 查询托盘信息列表
     *
     * @param mesBasePalletInfo 托盘信息
     * @return 托盘信息集合
     */
    public List<MesBasePalletInfo> selectMesBasePalletInfoList(MesBasePalletInfo mesBasePalletInfo);

    /**
     * 新增托盘信息
     *
     * @param mesBasePalletInfo 托盘信息
     * @return 结果
     */
    public int insertMesBasePalletInfo(MesBasePalletInfo mesBasePalletInfo);

    /**
     * 修改托盘信息
     *
     * @param mesBasePalletInfo 托盘信息
     * @return 结果
     */
    public int updateMesBasePalletInfo(MesBasePalletInfo mesBasePalletInfo);

    /**
     * 批量删除托盘信息
     *
     * @param palletInfoIds 需要删除的托盘信息主键集合
     * @return 结果
     */
    public int deleteMesBasePalletInfoByPalletInfoIds(Long[] palletInfoIds);

    /**
     * 删除托盘信息信息
     *
     * @param palletInfoId 托盘信息主键
     * @return 结果
     */
    public int deleteMesBasePalletInfoByPalletInfoId(Long palletInfoId);


    /**
     * 绑定托盘信息
     * @param mesPalletInfoBindVo
     * @return
     */
    public int bindPalletInfo(MesPalletInfoBindVo mesPalletInfoBindVo);
}
