package com.hw.mes.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.hw.common.security.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.mes.domain.MesBasePalletInfo;
import com.hw.mes.service.IMesBasePalletInfoService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 托盘信息Controller
 * 
 * @author Yinq
 * @date 2024-01-26
 */
@RestController
@RequestMapping("/basePalletInfo")
public class MesBasePalletInfoController extends BaseController
{
    @Autowired
    private IMesBasePalletInfoService mesBasePalletInfoService;

    /**
     * 查询托盘信息列表
     */
    @RequiresPermissions("mes:basePalletInfo:list")
    @GetMapping("/list")
    public TableDataInfo list(MesBasePalletInfo mesBasePalletInfo)
    {
        startPage();
        List<MesBasePalletInfo> list = mesBasePalletInfoService.selectMesBasePalletInfoList(mesBasePalletInfo);
        return getDataTable(list);
    }

    /**
     * 导出托盘信息列表
     */
    @RequiresPermissions("mes:basePalletInfo:export")
    @Log(title = "托盘信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MesBasePalletInfo mesBasePalletInfo)
    {
        List<MesBasePalletInfo> list = mesBasePalletInfoService.selectMesBasePalletInfoList(mesBasePalletInfo);
        ExcelUtil<MesBasePalletInfo> util = new ExcelUtil<MesBasePalletInfo>(MesBasePalletInfo.class);
        util.exportExcel(response, list, "托盘信息数据");
    }

    /**
     * 获取托盘信息详细信息
     */
    @RequiresPermissions("mes:basePalletInfo:query")
    @GetMapping(value = "/{palletInfoId}")
    public AjaxResult getInfo(@PathVariable("palletInfoId") Long palletInfoId)
    {
        return success(mesBasePalletInfoService.selectMesBasePalletInfoByPalletInfoId(palletInfoId));
    }

    /**
     * 新增托盘信息
     */
    @RequiresPermissions("mes:basePalletInfo:add")
    @Log(title = "托盘信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MesBasePalletInfo mesBasePalletInfo)
    {
        mesBasePalletInfo.setCreateBy(SecurityUtils.getLoginUser().getUsername());
        return toAjax(mesBasePalletInfoService.insertMesBasePalletInfo(mesBasePalletInfo));
    }

    /**
     * 修改托盘信息
     */
    @RequiresPermissions("mes:basePalletInfo:edit")
    @Log(title = "托盘信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MesBasePalletInfo mesBasePalletInfo)
    {
        mesBasePalletInfo.setUpdateBy(SecurityUtils.getLoginUser().getUsername());
        return toAjax(mesBasePalletInfoService.updateMesBasePalletInfo(mesBasePalletInfo));
    }

    /**
     * 删除托盘信息
     */
    @RequiresPermissions("mes:basePalletInfo:remove")
    @Log(title = "托盘信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{palletInfoIds}")
    public AjaxResult remove(@PathVariable Long[] palletInfoIds)
    {
        return toAjax(mesBasePalletInfoService.deleteMesBasePalletInfoByPalletInfoIds(palletInfoIds));
    }
}
